@@ -871,7 +871,7 @@ static void dosession(TCMPOOL *mpool){
         tcmapputkeep2(cols, "cancom", "true");
       }
       const char *name = tcmapget2(cols, "name");
-      if(name) tcmapprintf(vars, "titletip", name);
+      if(name) tcmapput2(vars, "titletip", name);
       if(!strcmp(p_adjust, "front")){
         tcmapput2(vars, "view", "front");
       } else {
@@ -914,7 +914,7 @@ static void dosession(TCMPOOL *mpool){
           tcmapputkeep2(cols, "cancom", "true");
         }
         const char *name = tcmapget2(cols, "name");
-        if(name) tcmapprintf(vars, "titletip", name);
+        if(name) tcmapput2(vars, "titletip", name);
         if(!strcmp(p_adjust, "front")){
           tcmapput2(vars, "view", "front");
         } else {
@@ -1132,8 +1132,8 @@ static void dosession(TCMPOOL *mpool){
         rp = tcmapget2(cols, "comments");
         if(rp && *rp != '\0'){
           TCLIST *lines = tcmpoolpushlist(mpool, tcstrsplit(rp, "\n"));
-          int cnum = tclistnum(lines);
-          for(int i = 0; i < cnum && i < g_sidebarnum; i++){
+          int left = g_sidebarnum;
+          for(int i = tclistnum(lines) - 1; i >= 0 && left > 0; i--, left--){
             rp = tclistval2(lines, i);
             char *co = strchr(rp, '|');
             if(co){
@@ -1445,20 +1445,10 @@ static TCLIST *searcharts(TCMPOOL *mpool, TCTDB *tdb, const char *cond, const ch
     if(ls) tctdbqryaddcond(qrys[i], "tags", TDBQCSTROR | TDBQCNEGATE, "?");
     tctdbqrysetorder(qrys[i], oname, otype);
   }
-  TCLIST *res;
-  if(qnum < 2){
-    tctdbqrysetlimit(qrys[0], max, skip);
-    res = tcmpoolpushlist(mpool, tctdbqrysearch(qrys[0]));
-  } else {
-    for(int i = 0; i < qnum; i++){
-      tctdbqrysetlimit(qrys[i], max + skip, 0);
-    }
-    res = tcmpoolpushlist(mpool, tctdbmetasearch(qrys, qnum, TDBMSUNION));
-    skip = tclmin(skip, tclistnum(res));
-    for(int i = 0; i < skip; i++){
-      tcfree(tclistshift2(res));
-    }
+  for(int i = 0; i < qnum; i++){
+    tctdbqrysetlimit(qrys[i], max, skip);
   }
+  TCLIST *res = tcmpoolpushlist(mpool, tctdbmetasearch(qrys, qnum, TDBMSUNION));
   return res;
 }
 
