@@ -28,12 +28,14 @@ static void printdberr(TCTDB *tdb);
 static int runcreate(int argc, char **argv);
 static int runimport(int argc, char **argv);
 static int runexport(int argc, char **argv);
+static int runremove(int argc, char **argv);
 static int runconvert(int argc, char **argv);
 static int runpasswd(int argc, char **argv);
 static int runversion(int argc, char **argv);
 static int proccreate(const char *dbpath, int scale, bool fts);
 static int procimport(const char *dbpath, TCLIST *files, TCLIST *sufs);
 static int procexport(const char *dbpath, int64_t id, const char *dirpath);
+static int procremove(const char *dbpath, int64_t id);
 static int procconvert(const char *ibuf, int isiz, int fmt,
                        const char *buri, const char *duri, bool page);
 static int procpasswd(const char *name, const char *pass, const char *salt, const char *info);
@@ -51,6 +53,8 @@ int main(int argc, char **argv){
     rv = runimport(argc, argv);
   } else if(!strcmp(argv[1], "export")){
     rv = runexport(argc, argv);
+  } else if(!strcmp(argv[1], "remove")){
+    rv = runremove(argc, argv);
   } else if(!strcmp(argv[1], "convert")){
     rv = runconvert(argc, argv);
   } else if(!strcmp(argv[1], "passwd")){
@@ -72,6 +76,7 @@ static void usage(void){
   fprintf(stderr, "  %s create [-fts] dbpath [scale]\n", g_progname);
   fprintf(stderr, "  %s import [-suf str] dbpath file ... \n", g_progname);
   fprintf(stderr, "  %s export [-dir str] dbpath [id]\n", g_progname);
+  fprintf(stderr, "  %s remove dbpath id\n", g_progname);
   fprintf(stderr, "  %s convert [-fw|-ft] [-buri str] [-duri] [-page] [file]\n", g_progname);
   fprintf(stderr, "  %s passwd [-salt str] [-info str] name pass\n", g_progname);
   fprintf(stderr, "  %s version\n", g_progname);
@@ -157,7 +162,6 @@ static int runexport(int argc, char **argv){
   char *dbpath = NULL;
   char *idstr = NULL;
   char *dirpath = NULL;
-  int64_t id = 0;
   for(int i = 2; i < argc; i++){
     if(!dbpath && argv[i][0] == '-'){
       if(!strcmp(argv[i], "-dir")){
@@ -175,12 +179,35 @@ static int runexport(int argc, char **argv){
     }
   }
   if(!dbpath) usage();
-  if(idstr) id = tcatoi(idstr);
+  int64_t id = idstr ? tcatoi(idstr) : 0;
   int rv = procexport(dbpath, id, dirpath);
   return rv;
 }
 
 
+/* parse arguments of remove command */
+static int runremove(int argc, char **argv){
+  char *dbpath = NULL;
+  char *idstr = NULL;
+  for(int i = 2; i < argc; i++){
+    if(!dbpath && argv[i][0] == '-'){
+      usage();
+    } else if(!dbpath){
+      dbpath = argv[i];
+    } else if(!idstr){
+      idstr = argv[i];
+    } else {
+      usage();
+    }
+  }
+  if(!dbpath || !idstr) usage();
+  int64_t id = tcatoi(idstr);
+  if(id < 1) usage();
+  int rv = procremove(dbpath, id);
+  return rv;
+}
+
+
 /* parse arguments of convert command */
 static int runconvert(int argc, char **argv){
   char *path = NULL;
@@ -464,6 +491,28 @@ static int procexport(const char *dbpath, int64_t id, const char *dirpath){
 }
 
 
+/* perform remove command */
+static int procremove(const char *dbpath, int64_t id){
+  TCTDB *tdb = tctdbnew();
+  if(!tctdbopen(tdb, dbpath, TDBOWRITER)){
+    printdberr(tdb);
+    tctdbdel(tdb);
+    return 1;
+  }
+  bool err = false;
+  if(!dboutart(tdb, id)){
+    printdberr(tdb);
+    err = true;
+  }
+  if(!tctdbclose(tdb)){
+    printdberr(tdb);
+    err = true;
+  }
+  tctdbdel(tdb);
+  return err ? 1 : 0;
+}
+
+
 /* perform convert command */
 static int procconvert(const char *ibuf, int isiz, int fmt,
                        const char *buri, const char *duri, bool page){
